@@ -1,12 +1,11 @@
 package Bot::Training;
 BEGIN {
-  $Bot::Training::VERSION = '0.03';
+  $Bot::Training::VERSION = '0.04';
 }
 
 use 5.010;
 use autodie qw(open close);
 use Any::Moose;
-use Any::Moose 'X::Types::'.any_moose() => [qw/Bool Int Str/];
 use Module::Pluggable (
     search_path => [ 'Bot::Training' ],
     except      => [ 'Bot::Training::Plugin' ],
@@ -20,7 +19,7 @@ has help => (
     traits        => [ qw/ Getopt / ],
     cmd_aliases   => 'h',
     cmd_flag      => 'help',
-    isa           => Bool,
+    isa           => 'Bool',
     is            => 'ro',
     default       => 0,
     documentation => 'This help message',
@@ -31,7 +30,7 @@ has _go_version => (
     cmd_aliases   => 'v',
     cmd_flag      => 'version',
     documentation => 'Print version and exit',
-    isa           => Bool,
+    isa           => 'Bool',
     is            => 'ro',
 );
 
@@ -40,7 +39,7 @@ has _go_list => (
     cmd_aliases   => 'l',
     cmd_flag      => 'list',
     documentation => 'List the known Bot::Training files. Install Task::Bot::Training to get them all',
-    isa           => Bool,
+    isa           => 'Bool',
     is            => 'ro',
 );
 
@@ -49,7 +48,7 @@ has _go_file => (
     cmd_aliases   => 'f',
     cmd_flag      => 'file',
     documentation => 'The file to retrieve. Matched case-insensitively against Bot::Training plugins',
-    isa           => Str,
+    isa           => 'Str',
     is            => 'ro',
 );
 
